pub struct CallHandlerArgs {
pub escrow_index: u8,
pub data: Vec<u8>,
}Fields
escrow_index: u8data: Vec<u8>This is raw instruction data, it could include discriminator + args or can be in any other custom format