pub struct CommitDiffArgs {
pub diff: Vec<u8>,
pub nonce: u64,
pub lamports: u64,
pub allow_undelegation: bool,
}Fields
diff: Vec<u8>The account diff
SAFETY: this must be the FIRST field in the struct because the serialized format
is manually split: the diff (with Borsh Vec prefix) followed by the fixed-size
fields. The processor uses data.split_at(data.len() - SIZE_COMMIT_DIFF_ARGS_WITHOUT_DIFF)
to separate them during deserialization.
nonce: u64“Nonce” of an account. Updates are submitted historically and nonce incremented by 1 Deprecated: The ephemeral slot at which the account data is committed
lamports: u64The lamports that the account holds in the ephemeral validator
allow_undelegation: boolWhether the account can be undelegated after the commit completes