#[repr(C)]pub struct CommitFinalizeArgs {
pub commit_id: u64,
pub lamports: u64,
pub allow_undelegation: Boolean,
pub data_is_diff: Boolean,
pub bumps: CommitBumps,
pub reserved_padding: [u8; 3],
}Fields
commit_id: u64the commit_id ensures correct ordering of commits
lamports: u64the lamports that the delegated account holds in the ephemeral validator
allow_undelegation: Booleanwhether the account can be undelegated after the commit completes
data_is_diff: Booleanwhether the data (in the ixdata or in the data account) is diff or full state.
bumps: CommitBumpsbumps of the PDA accounts to be validated by the ix
reserved_padding: [u8; 3]Trait Implementations
Sourceimpl Clone for CommitFinalizeArgs
impl Clone for CommitFinalizeArgs
Sourcefn clone(&self) -> CommitFinalizeArgs
fn clone(&self) -> CommitFinalizeArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for CommitFinalizeArgs
impl Pod for CommitFinalizeArgs