pub struct CommitStateFromBufferArgs {
pub nonce: u64,
pub lamports: u64,
pub allow_undelegation: bool,
}Fields
nonce: u64“Nonce” of an account. Updates are submitted historically and nonce incremented by 1 Deprecated: The ephemeral slot at which the account data is committed
lamports: u64The lamports that the account holds in the ephemeral validator
allow_undelegation: boolWhether the account can be undelegated after the commit completes