pub struct DelegateArgs {
pub commit_frequency_ms: u32,
pub seeds: Vec<Vec<u8>>,
pub validator: Option<Pubkey>,
}Fields
commit_frequency_ms: u32The frequency at which the validator should commit the account data if no commit is triggered by the owning program
seeds: Vec<Vec<u8>>The seeds used to derive the PDA of the delegated account
validator: Option<Pubkey>The validator authority that is added to the delegation record