pub struct MaybeEncryptedInstruction {
pub program_id: u8,
pub accounts: Vec<MaybeEncryptedAccountMeta>,
pub data: MaybeEncryptedIxData,
}Fields
program_id: u8accounts: Vec<MaybeEncryptedAccountMeta>data: MaybeEncryptedIxDataTrait Implementations
Sourceimpl BorshDeserialize for MaybeEncryptedInstruction
impl BorshDeserialize for MaybeEncryptedInstruction
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for MaybeEncryptedInstruction
impl Clone for MaybeEncryptedInstruction
Sourcefn clone(&self) -> MaybeEncryptedInstruction
fn clone(&self) -> MaybeEncryptedInstruction
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for MaybeEncryptedInstruction
impl RefUnwindSafe for MaybeEncryptedInstruction
impl Send for MaybeEncryptedInstruction
impl Sync for MaybeEncryptedInstruction
impl Unpin for MaybeEncryptedInstruction
impl UnsafeUnpin for MaybeEncryptedInstruction
impl UnwindSafe for MaybeEncryptedInstruction