pub struct MaybeEncryptedIxData {
pub prefix: Vec<u8>,
pub suffix: EncryptedBuffer,
}Fields
prefix: Vec<u8>suffix: EncryptedBufferTrait Implementations
Sourceimpl BorshDeserialize for MaybeEncryptedIxData
impl BorshDeserialize for MaybeEncryptedIxData
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for MaybeEncryptedIxData
impl Clone for MaybeEncryptedIxData
Sourcefn clone(&self) -> MaybeEncryptedIxData
fn clone(&self) -> MaybeEncryptedIxData
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MaybeEncryptedIxData
impl Debug for MaybeEncryptedIxData
Sourceimpl Decrypt for MaybeEncryptedIxData
impl Decrypt for MaybeEncryptedIxData