PostDelegationActions

Struct PostDelegationActions 

pub struct PostDelegationActions {
    pub inserted_signers: u8,
    pub inserted_non_signers: u8,
    pub signers: Vec<[u8; 32]>,
    pub non_signers: Vec<MaybeEncryptedPubkey>,
    pub instructions: Vec<MaybeEncryptedInstruction>,
}
This struct is used both as instruction args and as persisted state: it is received as instruction data and then stored in the delegation-record account immediately after DelegationRecord.

In the basic form, PostDelegationActions is constructed from Vec. In that case, both inserted_signers and inserted_non_signers are zero, and the pubkey indices used by compact::AccountMeta are computed from this imagined pubkey list:

[signers.., non_signers..]

That is, the first non-signer pubkey index is signers.len().

In the advanced form, an existing PostDelegationActions value (usually provided by an off-chain client) is combined with Vec (usually constructed on-chain) to produce a merged PostDelegationActions via ClearTextWithInsertable::cleartext_with_insertable, which allows the existing actions to be inserted at a specific instruction index. In this case, both inserted_signers and inserted_non_signers may be non-zero, and the imagined pubkey list takes this form:

[old_signers.., old_non_signers.., new_signers.., new_non_signers..]

That is, the first “new signer” comes after the old keys (old_signers + old_non_signers). Also, the signers field is created from:

[old_signers.., new_signers..]

and non-signers field is created from:

[old_non_signers.., new_non_signers..]

Fields

inserted_signers: u8inserted_non_signers: u8signers: Vec<[u8; 32]>non_signers: Vec<MaybeEncryptedPubkey>instructions: Vec<MaybeEncryptedInstruction>