pub struct TopUpEphemeralBalanceArgs {
pub amount: u64,
pub index: u8,
}Fields
amount: u64The amount to add to the ephemeral balance.
index: u8The index of the ephemeral balance account to top up which allows one payer to have multiple ephemeral balance accounts.