Constants
- BPF_
LOADER_ UPGRADEABLE_ ID - BROADCAST_
IDENTITY - The broadcast identity marks an account as undelegatable. Validators treat it as always delegatable, which is safe since such accounts cannot be committed or delegated
- COMMIT_
FEE_ LAMPORTS - Fixed fee per commit (charged for each commit after the first).
- DEFAULT_
VALIDATOR_ IDENTITY - Default validator identity (used when none is provided during delegation).
- DELEGATION_
PROGRAM_ DATA_ ID - DELEGATION_
PROGRAM_ ID - The program ID of the delegation program.
- EXTERNAL_
UNDELEGATE_ DISCRIMINATOR - The discriminator for the external undelegate instruction.
- PROTOCOL_
FEES_ PERCENTAGE - The fees extracted from the validator earnings (extracted in percentage from the validator fees claims).
- RENT_
EXCEPTION_ ZERO_ BYTES_ LAMPORTS - RENT_
FEES_ PERCENTAGE - The delegation session fees (extracted in percentage from the delegation PDAs rent on closure).
- SESSION_
FEE_ LAMPORTS - Fixed fee per delegation session (0.0003 SOL).