Structs
Enums
Constants
Functions
- apply_
diff_ copy - This function creates a copy of original, possibly extending or shrinking it, and then applies the diff to it, before returning it.
- apply_
diff_ in_ place - This function applies the diff to the first argument (i.e original) to update it.
- compute_
diff - Compute diff between original and changed.
- detect_
size_ change - Detects if there is size change in the changed data.
- merge_
diff_ copy - Constructs destination by applying the diff to original, such that destination becomes the post-diff state of the original.