pub fn apply_diff_copy(
original: &[u8],
diffset: &DiffSet<'_>,
) -> Result<Vec<u8>, ProgramError>Expand description
This function creates a copy of original, possibly extending or shrinking it, and then applies the diff to it, before returning it.