apply_diff_in_place

Function apply_diff_in_place 

pub fn apply_diff_in_place(
    original: &mut [u8],
    diffset: &DiffSet<'_>,
) -> Result<(), ProgramError>
This function applies the diff to the first argument (i.e original) to update it.

Precondition:

  • original.len() must be equal to the length encoded in the diff.