pub struct DiffSet<'a> { /* private fields */ }Implementations
Sourceimpl<'a> DiffSet<'a>
impl<'a> DiffSet<'a>
pub fn try_new(diff: &'a [u8]) -> Result<Self, ProgramError>
pub fn try_new_from_borsh_vec( vec_buffer: &'a [u8], ) -> Result<Self, ProgramError>
pub fn raw_diff(&self) -> &'a [u8] ⓘ
Sourcepub fn changed_len(&self) -> usize
pub fn changed_len(&self) -> usize
Returns the length of the changed data (not diff) that is passed as the second argument to compute_diff()
Sourcepub fn segments_count(&self) -> usize
pub fn segments_count(&self) -> usize
Returns the number of segments which is same as number of offset pairs.
Sourcepub fn offset_pairs(&self) -> &'a [OffsetPair]
pub fn offset_pairs(&self) -> &'a [OffsetPair]
Returns the offset pairs
Sourcepub fn diff_segment_at(
&self,
index: usize,
) -> Result<Option<(&'a [u8], OffsetInData)>, ProgramError>
pub fn diff_segment_at( &self, index: usize, ) -> Result<Option<(&'a [u8], OffsetInData)>, ProgramError>
Given an index, returns a diff-segment and offset-range [start,end) where the returned diff-segment is to be applied in the original data.
Sourcepub fn iter(
&self,
) -> impl Iterator<Item = Result<(&'a [u8], OffsetInData), ProgramError>> + '_
pub fn iter( &self, ) -> impl Iterator<Item = Result<(&'a [u8], OffsetInData), ProgramError>> + '_
Iterates diff segments