EncryptableFrom

Trait EncryptableFrom 

pub trait EncryptableFrom: Sized {
    type Output;

    // Required method
    fn encrypted_from(self, offset: usize) -> Self::Output;
}

Required Associated Types

Required Methods

fn encrypted_from(self, offset: usize) -> Self::Output

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl EncryptableFrom for Vec<u8>

Source

impl EncryptableFrom for Instruction

Instruction is never encrypted and only its parts are encrypted; and this Encryptable implementation is a shorthand for calling encrypted() and encrypted_from(offset) on all its parts.

Implementors