Module state

Module state 

Modules

discriminator
to_bytes
try_from_bytes

Structs

CommitRecord
The Commit State Record
DelegationMetadata
The Delegated Metadata includes Account Seeds, max delegation time, seeds and other meta information about the delegated account.
DelegationMetadataFast
DelegationRecord
The Delegation Record stores information such as the authority, the owner and the commit frequency. This is used by the ephemeral validator to update the state of the delegated account.
ProgramConfig