DelegationRecord

Struct DelegationRecord 

#[repr(C)]
pub struct DelegationRecord { pub authority: Pubkey, pub owner: Pubkey, pub delegation_slot: u64, pub lamports: u64, pub commit_frequency_ms: u64, }
The Delegation Record stores information such as the authority, the owner and the commit frequency. This is used by the ephemeral validator to update the state of the delegated account.

Fields

authority: Pubkey

The delegated authority

owner: Pubkey

The original owner of the account

delegation_slot: u64

The slot at which the delegation was created

lamports: u64

The lamports at the time of delegation or from the last state finalization, stored as lamports can be received even if the account is delegated

commit_frequency_ms: u64

The state update frequency in milliseconds

Implementations