pub struct PostDelegationActions {
pub inserted_signers: u8,
pub inserted_non_signers: u8,
pub signers: Vec<[u8; 32]>,
pub non_signers: Vec<MaybeEncryptedPubkey>,
pub instructions: Vec<MaybeEncryptedInstruction>,
}Expand description
This struct is used both as instruction args and as persisted state: it is received as instruction data and then stored in the delegation-record account immediately after DelegationRecord.
In the basic form, PostDelegationActions is constructed from Vec
[signers.., non_signers..]
That is, the first non-signer pubkey index is signers.len().
In the advanced form, an existing PostDelegationActions value (usually provided by an off-chain
client) is combined with Vec
[old_signers.., old_non_signers.., new_signers.., new_non_signers..]
That is, the first “new signer” comes after the old keys (old_signers + old_non_signers). Also,
the signers field is created from:
[old_signers.., new_signers..]
and non-signers field is created from:
[old_non_signers.., new_non_signers..]
Fields
inserted_signers: u8inserted_non_signers: u8signers: Vec<[u8; 32]>non_signers: Vec<MaybeEncryptedPubkey>instructions: Vec<MaybeEncryptedInstruction>Trait Implementations
Sourceimpl BorshDeserialize for PostDelegationActions
impl BorshDeserialize for PostDelegationActions
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Debug for PostDelegationActions
impl Debug for PostDelegationActions
Sourceimpl Decrypt for PostDelegationActions
impl Decrypt for PostDelegationActions
Sourcefn decrypt(
self,
recipient_x25519_pubkey: &[u8; 32],
recipient_x25519_secret: &[u8; 32],
) -> Result<Self::Output, DecryptError>
fn decrypt( self, recipient_x25519_pubkey: &[u8; 32], recipient_x25519_secret: &[u8; 32], ) -> Result<Self::Output, DecryptError>
This function decrypts PostDelegationActions as well as validates it, matching the expected signers with the AccountMetas.
type Output = Vec<Instruction>
fn decrypt_with_keypair(
self,
recipient_keypair: &Keypair,
) -> Result<Self::Output, DecryptError>where
Self: Sized,