pub struct PostDelegationActions {
pub inserted_signers: u8,
pub inserted_non_signers: u8,
pub signers: Vec<[u8; 32]>,
pub non_signers: Vec<MaybeEncryptedPubkey>,
pub instructions: Vec<MaybeEncryptedInstruction>,
}Fields
inserted_signers: u8inserted_non_signers: u8signers: Vec<[u8; 32]>non_signers: Vec<MaybeEncryptedPubkey>instructions: Vec<MaybeEncryptedInstruction>Trait Implementations
Sourceimpl BorshDeserialize for PostDelegationActions
impl BorshDeserialize for PostDelegationActions
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Debug for PostDelegationActions
impl Debug for PostDelegationActions
Sourceimpl Decrypt for PostDelegationActions
impl Decrypt for PostDelegationActions