Module diff

Module diff 

Structs

DiffSet
OffsetPair

Enums

SizeChanged

Constants

SIZE_OF_CHANGED_LEN
SIZE_OF_NUM_OFFSET_PAIRS
SIZE_OF_SINGLE_OFFSET_PAIR

Functions

apply_diff_copy
This function creates a copy of original, possibly extending or shrinking it, and then applies the diff to it, before returning it.
apply_diff_in_place
This function applies the diff to the first argument (i.e original) to update it.
compute_diff
Compute diff between original and changed.
detect_size_change
Detects if there is size change in the changed data.
merge_diff_copy
Constructs destination by applying the diff to original, such that destination becomes the post-diff state of the original.

Type Aliases

OffsetInData