pub trait Encryptable: Sized {
type Output;
// Required method
fn with_encryption(self, encrypt: bool) -> Self::Output;
// Provided methods
fn encrypted(self) -> Self::Output { ... }
fn cleartext(self) -> Self::Output { ... }
}Required Associated Types
Required Methods
fn with_encryption(self, encrypt: bool) -> Self::Output
Provided Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementations on Foreign Types
Sourceimpl Encryptable for AccountMeta
impl Encryptable for AccountMeta
type Output = EncryptableAccountMeta
fn with_encryption(self, encrypt: bool) -> Self::Output
Sourceimpl Encryptable for Instruction
Instruction is never encrypted and only its parts are encrypted;
and this Encryptable implementation is a shorthand for calling
encrypted() and encrypted_from(0) on all its parts.
impl Encryptable for Instruction
Instruction is never encrypted and only its parts are encrypted; and this Encryptable implementation is a shorthand for calling encrypted() and encrypted_from(0) on all its parts.