pub trait EncryptableFrom: Sized {
type Output;
// Required method
fn encrypted_from(self, offset: usize) -> Self::Output;
}Required Associated Types
Required Methods
fn encrypted_from(self, offset: usize) -> Self::Output
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementations on Foreign Types
Sourceimpl EncryptableFrom for Vec<u8>
impl EncryptableFrom for Vec<u8>
type Output = EncryptableIxData
fn encrypted_from(self, offset: usize) -> Self::Output
Sourceimpl EncryptableFrom for Instruction
Instruction is never encrypted and only its parts are encrypted;
and this Encryptable implementation is a shorthand for calling
encrypted() and encrypted_from(offset) on all its parts.
impl EncryptableFrom for Instruction
Instruction is never encrypted and only its parts are encrypted; and this Encryptable implementation is a shorthand for calling encrypted() and encrypted_from(offset) on all its parts.