pub struct DelegationMetadata {
pub last_update_nonce: u64,
pub is_undelegatable: bool,
pub seeds: Vec<Vec<u8>>,
pub rent_payer: Pubkey,
}Expand description
The Delegated Metadata includes Account Seeds, max delegation time, seeds and other meta information about the delegated account.
- Everything necessary at cloning time is instead stored in the delegation record.
Fields
last_update_nonce: u64The last nonce account had during delegation update Deprecated: The last slot at which the delegation was updated
is_undelegatable: boolWhether the account can be undelegated or not
seeds: Vec<Vec<u8>>The seeds of the account, used to reopen it on undelegation
rent_payer: PubkeyThe account that paid the rent for the delegation PDAs
Implementations
Sourceimpl DelegationMetadata
impl DelegationMetadata
pub fn serialized_size(&self) -> usize
Sourceimpl DelegationMetadata
impl DelegationMetadata
pub fn to_bytes_with_discriminator<W: Write>( &self, writer: &mut W, ) -> Result<(), ProgramError>
Sourceimpl DelegationMetadata
impl DelegationMetadata
pub fn try_from_bytes_with_discriminator( data: &[u8], ) -> Result<Self, ProgramError>