#[repr(C)]pub struct DelegationRecord {
pub authority: Pubkey,
pub owner: Pubkey,
pub delegation_slot: u64,
pub lamports: u64,
pub commit_frequency_ms: u64,
}Expand description
The Delegation Record stores information such as the authority, the owner and the commit frequency. This is used by the ephemeral validator to update the state of the delegated account.
Fields
The delegated authority
owner: PubkeyThe original owner of the account
delegation_slot: u64The slot at which the delegation was created
lamports: u64The lamports at the time of delegation or from the last state finalization, stored as lamports can be received even if the account is delegated
commit_frequency_ms: u64The state update frequency in milliseconds
Implementations
Sourceimpl DelegationRecord
impl DelegationRecord
pub fn size_with_discriminator() -> usize
Sourceimpl DelegationRecord
impl DelegationRecord
pub fn to_bytes_with_discriminator( &self, data: &mut [u8], ) -> Result<(), ProgramError>
Sourceimpl DelegationRecord
impl DelegationRecord
pub fn try_from_bytes_with_discriminator( data: &[u8], ) -> Result<&Self, ProgramError>
pub fn try_from_bytes_with_discriminator_mut( data: &mut [u8], ) -> Result<&mut Self, ProgramError>